@@ -21,7 +21,184 @@ use Params::Validate qw(validate_with validate_pos :types);
 #######################
 # VERSION
 #######################
-our $VERSION = '0.4.1';
+our $VERSION = '0.01';
+
+#######################
+# PARAM SPECS
+#######################
+
+# Load spec
+my %pv_load_spec = (
+
+    # List delimiter - this identifies multi-token values
+    token_delimiter => {
+        optional => 1,
+        type     => SCALAR | UNDEF,
+        default  => ',',
+    },
+
+    # Include keyword
+    include_keyword => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[^\s]+$}x,
+        default  => 'include',
+    },
+
+    # Include basedir
+    includes_basepath => {
+        optional => 1,
+        type     => SCALAR | UNDEF,
+        default  => undef,
+    },
+
+    # Process Includes?
+    process_includes => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[01]$}x,
+        default  => 1,
+    },
+
+    # Allow recursive includes?
+    cache_files => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[01]$}x,
+        default  => 1,
+    },
+
+    # Process property interpolation?
+    interpolation => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[01]$}x,
+        default  => 1,
+    },
+
+    # Force values to be array-refs
+    force_value_arrayref => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[01]$}x,
+        default  => 0,
+    },
+
+    # Allow callback
+    callback => {
+        optinal => 1,
+        type    => CODEREF,
+        default => sub { return @_; },
+    },
+
+    # Allow defaults
+    defaults => {
+        optional => 1,
+        type     => HASHREF,
+        default  => {},
+    },
+
+    # Allow filename for auto-load
+    load_file => {
+        optional => 1,
+        type     => SCALAR | HANDLE | UNDEF,
+        default  => undef,
+    },
+);
+
+# Save Spec
+my %pv_save_spec = (
+
+    # Save properties with multiple value tokens on a single line
+    save_combine_tokens => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[01]$}x,
+        default  => 0,
+    },
+
+    # Wrap and save
+    save_wrapped => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^[01]$}x,
+        default  => 1,
+    },
+
+    # Wrap length
+    save_wrapped_len => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^\d+$}x,
+        default  => 76,
+    },
+
+    # key=value separator
+    save_separator => {
+        optional => 1,
+        type     => SCALAR,
+        regex    => qr{^\s*[=:\s]\s*$}x,
+        default  => ' = ',
+    },
+
+    # Save sorting routine
+    save_sorter => {
+        optional => 1,
+        type     => CODEREF,
+        default  => sub ($$) { lc( $_[0] ) cmp lc( $_[1] ); },
+    },
+
+    # Save Header
+    save_header => {
+        optional => 1,
+        type     => SCALAR,
+        default  => '#' x 15,
+    },
+
+    # Save footer
+    save_footer => {
+        optional => 1,
+        type     => SCALAR,
+        default  => '#' x 15,
+    },
+);
+
+# Option aliases
+my %option_aliases = (
+
+    # __PACKAGE__
+    delimiter      => 'token_delimiter',
+    include        => 'include_keyword',
+    basepath       => 'includes_basepath',
+    includes_allow => 'process_includes',
+    cache          => 'cache_files',
+    interpolate    => 'interpolation',
+    force_arrayref => 'force_value_arrayref',
+    validate       => 'callback',
+    filename       => 'load_file',
+    single_line    => 'save_combine_tokens',
+    wrap           => 'save_wrapped',
+    columns        => 'save_wrapped_len',
+    separator      => 'save_separator',
+    header         => 'save_header',
+    footer         => 'save_footer',
+
+    # Java Style
+    setListDelimiter   => 'token_delimiter',
+    setInclude         => 'include_keyword',
+    setIncludesAllowed => 'process_includes',
+    setBasePath        => 'includes_basepath',
+);
+
+# Normalizer
+#   Allow leading '-' and make case-insensitive
+my $pv_key_normalizer = sub {
+    my ($_key) = @_;
+    $_key = no_space($_key);
+    $_key =~ s{^\-+}{}x;
+    $_key = lc($_key);
+    return $_key;
+};
 
 #######################
 # CONSTRUCTOR
@@ -29,32 +206,47 @@ our $VERSION = '0.4.1';
 sub new {
     my ( $class, @args ) = @_;
 
+    # Process Options
+    my %options = validate_with(
+
+        # Name used in validation errors
+        called => __PACKAGE__ . '::new',
+
+        # Options to process
+        params => \@args,
+
+        # Normalize key names.
+        normalize_keys => $pv_key_normalizer,
+
+        # Do not Allow extra options
+        allow_extra => 0,
+
+        # Option Spec
+        spec => { %pv_load_spec, %pv_save_spec, },
+    );
+
+    # Get default properties
+    my %defaults = %{ $options{defaults} };
+
     # Bless object
     my $self = {
-        _options      => {},
+        _options      => \%options,
         _seen_files   => {},
         _current_file => {
             name => '',
             base => '',
         },
-        _properties => {},
+        _properties => {%defaults},
     };
     bless $self, $class;
 
-    # Process Options
-    my %options = %{ $self->_set_options(@args) };
-    $self->{_options} = {%options};
-
-    # Get default properties
-    $self->{_properties} = $options{defaults};
-
     # Short-circuit _load_ if a filename is defined
     if ( defined $options{load_file} ) {
         $self->load( $options{load_file} );
     }
 
     # Return object
-  return $self;
+    return $self;
 } ## end sub new
 
 #######################
@@ -67,7 +259,7 @@ sub new {
 sub load {
     my ( $self, $from, @args ) = @_;
     croak "File name/handle to load from is not provided"
-      unless defined $from;
+        unless defined $from;
 
     # Process Options
     my %options = %{ $self->_set_options(@args) };
@@ -87,8 +279,9 @@ sub load {
         $self->{_current_file}->{base} = dirname($file);
 
         # Process file?
-      return 1
-          if ( $options{cache_files} and $self->{_seen_files}->{$file} );
+        return 1
+            if ($options{cache_files}
+            and $self->{_seen_files}->{$file} );
 
         # Mark as seen
         $self->{_seen_files}->{$file} = 1;
@@ -109,7 +302,7 @@ sub load {
         }
     );
 
-  return 1;
+    return 1;
 } ## end sub load
 
 # =====================
@@ -117,27 +310,23 @@ sub load {
 # =====================
 sub get_property {
     my ( $self, $key ) = @_;
-  return unless exists $self->{_properties}->{$key};
-  return $self->{_properties}->{$key};
-} ## end sub get_property
-
+    return unless exists $self->{_properties}->{$key};
+    return $self->{_properties}->{$key};
+}
 
 sub require_property {
     my ( $self, $key ) = @_;
     croak "Property for $key is not set"
-      unless exists $self->{_properties}->{$key};
-  return $self->get_property($key);
+        unless exists $self->{_properties}->{$key};
+    return $self->get_property($key);
 } ## end sub require_property
 
-
 sub add_property {
     my ( $self, @args )   = @_;
     my ( $key,  $values ) = validate_pos(
-        @args, {
-            type => SCALAR,
-        }, {
-            type => SCALAR | ARRAYREF,
-        },
+        @args,
+        { type => SCALAR, },
+        { type => SCALAR | ARRAYREF, },
     );
 
     my @new_values;
@@ -146,9 +335,9 @@ sub add_property {
     @new_values = ref($values) ? @{$values} : ($values);
 
     if ( defined $old_value ) {
-        $save
-          = [ ( ref($old_value) ? @{$old_value} : $old_value ), @new_values ];
-    } ## end if ( defined $old_value)
+        $save = [ ( ref($old_value) ? @{$old_value} : $old_value ),
+            @new_values ];
+    }
     else {
         if ( $self->{_options}->{force_value_arrayref} ) {
             $save = [@new_values];
@@ -156,12 +345,12 @@ sub add_property {
         else {
             if   ( scalar(@new_values) > 1 ) { $save = [@new_values]; }
             else                             { $save = $new_values[0]; }
-        } ## end else [ if ( $self->{_options}...)]
+        }
     } ## end else [ if ( defined $old_value)]
 
-  return unless defined $save;
+    return unless defined $save;
     $self->{_properties}->{$key} = $save;
-  return 1;
+    return 1;
 } ## end sub add_property
 
 # =====================
@@ -180,17 +369,16 @@ sub properties {
             my $_p = $_prop;
             $_p =~ s{^${prefix}}{}gx;
             $props{$_p} = $_props{$_prop};
-        } ## end foreach my $_prop ( grep { ...})
+        }
     } ## end if ( defined $prefix )
     else {
         %props = %_props;
     }
 
-  return %props if wantarray;
-  return {%props};
+    return %props if wantarray;
+    return {%props};
 } ## end sub properties
 
-
 sub property_names {
     my ( $self, $prefix ) = @_;
     my %props   = $self->properties();
@@ -199,23 +387,21 @@ sub property_names {
     if ( defined $prefix ) {
         @names = grep { /^${prefix}/x } @names;
     }
-  return @names;
+    return @names;
 } ## end sub property_names
 
-
 sub is_empty {
     my ($self) = @_;
     my @keys = $self->property_names();
-  return if scalar(@keys);
-  return 1;
+    return if scalar(@keys);
+    return 1;
 } ## end sub is_empty
 
-
 sub has_property {
     my ( $self, @args ) = @_;
     my $val = $self->get_property(@args);
-  return 1 if defined $val;
-  return;
+    return 1 if defined $val;
+    return;
 } ## end sub has_property
 
 # =====================
@@ -223,27 +409,27 @@ sub has_property {
 # =====================
 sub delete_property {
     my ( $self, $key ) = @_;
-  return unless ( defined $key and hascontent($key) );
+    return
+        unless ( defined $key
+        and hascontent($key) );
 
-  return 1 unless exists $self->{_properties}->{$key};
+    return 1 unless exists $self->{_properties}->{$key};
     delete $self->{_properties}->{$key};
-  return 1;
+    return 1;
 } ## end sub delete_property
 
-
 sub clear_properties {
     my ($self) = @_;
     $self->{_properties} = {};
     $self->{_seen_files} = {};
-  return 1;
+    return 1;
 } ## end sub clear_properties
 
-
 sub reset_property {
     my ( $self, @args ) = @_;
     $self->delete_property(@args) or return;
     $self->add_property(@args)    or return;
-  return 1;
+    return 1;
 } ## end sub reset_property
 
 # =====================
@@ -256,33 +442,23 @@ sub save_to_string {
     my %options = %{ $self->_set_options(@args) };
 
     # Get string to save
-    my $save_string = $self->_save(
-        {
-            options => \%options,
-        }
-    );
+    my $save_string = $self->_save( { options => \%options, } );
 
-  return $save_string;
+    return $save_string;
 } ## end sub save_to_string
 
-
 sub save {
     my ( $self, $to, @args ) = @_;
-  return unless defined $to;
+    return unless defined $to;
 
     # Get a string dump
     my $str = $self->save_to_string(@args);
 
     # Write to file/handle
-    write_file(
-        $to, {
-            binmode => ':utf8',
-        },
-        Encode::encode_utf8($str)
-    );
+    write_file( $to, { binmode => ':utf8', }, Encode::encode_utf8($str) );
 
     # Done
-  return 1;
+    return 1;
 } ## end sub save
 
 # =====================
@@ -291,8 +467,8 @@ sub save {
 sub get_files_loaded {
     my ($self) = @_;
     my @files = sort { lc $a cmp lc $b } keys %{ $self->{_seen_files} };
-  return @files;
-} ## end sub get_files_loaded
+    return @files;
+}
 
 #######################
 # METHOD ALIASES
@@ -345,185 +521,6 @@ sub _set_options {
         }
     } ## end if (@args)
 
-    # ---------------------
-    # PARAM SPEC
-    # ---------------------
-
-    # Load spec
-    my %pv_load_spec = (
-
-        # List delimiter - this identifies multi-token values
-        token_delimiter => {
-            optional => 1,
-            type     => SCALAR | UNDEF,
-            default  => ',',
-        },
-
-        # Include keyword
-        include_keyword => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[^\s]+$}x,
-            default  => 'include',
-        },
-
-        # Include basedir
-        includes_basepath => {
-            optional => 1,
-            type     => SCALAR | UNDEF,
-            default  => undef,
-        },
-
-        # Process Includes?
-        process_includes => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[01]$}x,
-            default  => 1,
-        },
-
-        # Allow recursive includes?
-        cache_files => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[01]$}x,
-            default  => 1,
-        },
-
-        # Process property interpolation?
-        interpolation => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[01]$}x,
-            default  => 1,
-        },
-
-        # Force values to be array-refs
-        force_value_arrayref => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[01]$}x,
-            default  => 0,
-        },
-
-        # Allow callback
-        callback => {
-            optinal => 1,
-            type    => CODEREF,
-            default => sub { return @_; },
-        },
-
-        # Allow defaults
-        defaults => {
-            optional => 1,
-            type     => HASHREF,
-            default  => {},
-        },
-
-        # Allow filename for auto-load
-        load_file => {
-            optional => 1,
-            type     => SCALAR | HANDLE | UNDEF,
-            default  => undef,
-        },
-    );
-
-    # Save Spec
-    my %pv_save_spec = (
-
-        # Save properties with multiple value tokens on a single line
-        save_combine_tokens => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[01]$}x,
-            default  => 0,
-        },
-
-        # Wrap and save
-        save_wrapped => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^[01]$}x,
-            default  => 1,
-        },
-
-        # Wrap length
-        save_wrapped_len => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^\d+$}x,
-            default  => 76,
-        },
-
-        # key=value separator
-        save_separator => {
-            optional => 1,
-            type     => SCALAR,
-            regex    => qr{^\s*[=:\s]\s*$}x,
-            default  => ' = ',
-        },
-
-        # Save sorting routine
-        save_sorter => {
-            optional => 1,
-            type     => CODEREF,
-            default  => sub ($$) { lc( $_[0] ) cmp lc( $_[1] ); },
-        },
-
-        # Save Header
-        save_header => {
-            optional => 1,
-            type     => SCALAR,
-            default  => '#' x 15,
-        },
-
-        # Save footer
-        save_footer => {
-            optional => 1,
-            type     => SCALAR,
-            default  => '#' x 15,
-        },
-    );
-
-    # Option aliases
-    my %option_aliases = (
-
-        # __PACKAGE__
-        delimiter      => 'token_delimiter',
-        include        => 'include_keyword',
-        basepath       => 'includes_basepath',
-        includes_allow => 'process_includes',
-        cache          => 'cache_files',
-        interpolate    => 'interpolation',
-        force_arrayref => 'force_value_arrayref',
-        validate       => 'callback',
-        filename       => 'load_file',
-        single_line    => 'save_combine_tokens',
-        wrap           => 'save_wrapped',
-        columns        => 'save_wrapped_len',
-        separator      => 'save_separator',
-        header         => 'save_header',
-        footer         => 'save_footer',
-
-        # Java Style
-        setListDelimiter   => 'token_delimiter',
-        setInclude         => 'include_keyword',
-        setIncludesAllowed => 'process_includes',
-        setBasePath        => 'includes_basepath',
-    );
-
-    # Normalizer
-    #   Allow leading '-' and make case-insensitive
-    my $pv_key_normalizer = sub {
-        my ($_key) = @_;
-        $_key = no_space($_key);
-        $_key =~ s{^\-+}{}x;
-        $_key = lc($_key);
-      return $_key;
-    };
-
-    # ---------------------
-
     # Merge Options
     my $merged_options = $self->{_options};
     foreach my $_opt ( keys %{$in_options} ) {
@@ -534,8 +531,8 @@ sub _set_options {
         # Resolve Aliases
         if ( exists $option_aliases{$_opt} ) {
             $merged_options->{ $option_aliases{$_opt} }
-              = $in_options->{$_opt};
-        } ## end if ( exists $option_aliases...)
+                = $in_options->{$_opt};
+        }
         else {
             $merged_options->{$_opt} = $in_options->{$_opt};
         }
@@ -560,7 +557,7 @@ sub _set_options {
 
     );
 
-  return {%valid_options};
+    return \%valid_options;
 } ## end sub _set_options
 
 # =====================
@@ -572,7 +569,7 @@ sub _load {
     my %options = $in->{options} ? %{ $in->{options} } : ();
 
     # Check for empty file
-  return 1 unless @lines;
+    return 1 unless @lines;
 
     # Check and remote byte order mark
     if ( $lines[0] =~ m{^\x{FEFF}}x ) { shift @lines; }
@@ -587,16 +584,13 @@ sub _load {
         $line = fullchomp($line);
 
         # Skip Blank
-      next unless hascontent($line);
+        next unless hascontent($line);
 
         # Skip Comments
-      next if ( $line =~ m{^\s*(?:\#|\!)}x );
+        next if ( $line =~ m{^\s*(?:\#|\!)}x );
 
         # Trim leading whitespace
-        $line = trim(
-            $line,
-            right => 0,
-        );
+        $line = trim( $line, right => 0, );
 
         # Check for wrapped lines
         if ( $line =~ m{(?<!\\)\\\s*$}x ) {
@@ -606,10 +600,10 @@ sub _load {
             while (@lines) {
                 my $_wline = shift @lines;
                 $_wline = fullchomp($_wline);
-              next unless hascontent($_wline);
+                next unless hascontent($_wline);
 
                 push @wrapped_lines, $_wline;
-              last unless ( $_wline =~ m{(?<!\\)\\\s*$}x );
+                last unless ( $_wline =~ m{(?<!\\)\\\s*$}x );
             } ## end while (@lines)
 
             # Join them
@@ -620,10 +614,7 @@ sub _load {
                 $_wline =~ s{\\\s*$}{}x;
 
                 # Remove leading whitespace
-                $_wline = trim(
-                    $_wline,
-                    right => 0,
-                );
+                $_wline = trim( $_wline, right => 0, );
 
                 # Save
                 push @unwrapped, $_wline;
@@ -636,11 +627,11 @@ sub _load {
         my ( $key, $value ) = split( _sep_regex(), $line, 2 );
 
         # Verify key/value
-        #   Key is required. Value can be empty
-        if ( not( defined $key and hascontent($key) ) ) {
+        if ( ( not( defined $key and defined $value ) )
+            or not hascontent($key) )
+        {
             croak "Invalid key/value format! : $line \n";
         }
-        $value = '' unless ( defined $value and hascontent($value) );
 
         # Unescape
         $key   = _unesc_key($key);
@@ -648,22 +639,16 @@ sub _load {
 
         # Perform callback
         ( $key, $value ) = $options{callback}->( $key, $value );
-      next
-          unless ( ( defined $key and defined $value ) and hascontent($key) );
+        next
+            unless ( ( defined $key and defined $value )
+            and hascontent($key) );
 
         # Process tokens
         my @tokens;
-        if ( hascontent($value) ) {
-            if ( defined $options{token_delimiter} ) {
-                my $_delim = $options{token_delimiter};
-                foreach my $_token ( _split_tokens( $value, $_delim ) ) {
-                    push( @tokens, _unesc_delim( $_token, $_delim ) );
-                }
-            } ## end if ( defined $options{...})
-            else {
-                push( @tokens, $value );
-            }
-        } ## end if ( hascontent($value...))
+        if ( defined $options{token_delimiter} ) {
+            my $_delim = $options{token_delimiter};
+            @tokens = split( qr/(?<!\\) $_delim \s*/x, $value );
+        }
         else {
             push( @tokens, $value );
         }
@@ -672,10 +657,10 @@ sub _load {
         my @interpolated_tokens;
         if ( $options{interpolation} ) {
             foreach my $token (@tokens) {
-                $token
-                  =~ s/(?<!\\)\$\{([^}]+)\}/ $self->_interpolate({key => $1, options => \%options,}) /gex;
+                $token =~ s{(?<!\\)\$\{([^\}]+)\}}
+                    { $self->_interpolate({key => $1, options => \%options,}) }gex;
                 push( @interpolated_tokens, $token );
-            } ## end foreach my $token (@tokens)
+            }
         } ## end if ( $options{interpolation...})
         else {
             push( @interpolated_tokens, @tokens );
@@ -689,7 +674,7 @@ sub _load {
             my $_basedir = $self->{_current_file}->{base};
             $_basedir = File::Spec->curdir() if not $_basedir;
             $_basedir = $options{includes_basepath}
-              if defined $options{includes_basepath};
+                if defined $options{includes_basepath};
 
             foreach my $_file (@interpolated_tokens) {
 
@@ -698,16 +683,20 @@ sub _load {
                     $_file = abs_path($_file);
                 }
                 else {
-                    $_file
-                      = abs_path( File::Spec->catfile( $_basedir, $_file ) );
-                } ## end else [ if ( File::Spec->file_name_is_absolute...)]
+                    $_file = abs_path(
+                        File::Spec->catfile( $_basedir, $_file ) );
+                }
+
+                # Verify file
+                next if not $_file;
+                next if not -f $_file;
 
                 # Check if this is the current file being processed
                 if ( $_file eq $self->{_current_file}->{name} ) {
 
                     # Skip it. Otherwise this is an infinite loop
-                  next;
-                } ## end if ( $_file eq $self->...)
+                    next;
+                }
 
                 # Load file
                 my %tmp_cf = %{ $self->{_current_file} };
@@ -717,18 +706,18 @@ sub _load {
 
             # Move onto next line
             # i.e., do not save an 'include'
-          next;
+            next;
         } ## end if ( $options{process_includes...})
 
         # Save key/value
         my $tmp_fvaf = $self->{_options}->{force_value_arrayref};
         $self->{_options}->{force_value_arrayref}
-          = $options{force_value_arrayref};
+            = $options{force_value_arrayref};
         $self->add_property( $key, [@interpolated_tokens] );
         $self->{_options}->{force_value_arrayref} = $tmp_fvaf;
     } ## end while (@lines)
 
-  return 1;
+    return 1;
 } ## end sub _load
 
 # =====================
@@ -742,9 +731,9 @@ sub _interpolate {
     # Defaults to original
     my $int_key = '${' . $key . '}';
 
-    # Return if key is not set
-    if ( not exists $self->{_properties}->{$key} ) {
-      return $int_key;
+    # Return if key is not defined
+    if ( not defined $self->{_properties}->{$key} ) {
+        return $int_key;
     }
 
     # Get defined key
@@ -754,7 +743,7 @@ sub _interpolate {
     if ( ref $def_key ) {
 
         # Return if defined key has multiple values
-      return $int_key if ( scalar( @{$def_key} ) > 1 );
+        return $int_key if ( scalar( @{$def_key} ) > 1 );
 
         # Do interpolation if we are forcing array refs
         if ( $options{force_value_arrayref} ) {
@@ -765,9 +754,7 @@ sub _interpolate {
         $int_key = $def_key;
     }
 
-    # Return empty if undef
-  return '' unless defined $int_key;
-  return $int_key;
+    return $int_key;
 } ## end sub _interpolate
 
 # =====================
@@ -798,22 +785,21 @@ sub _save {
     # Do wrap?
     my $do_wrap = $options{save_wrapped};
     $do_wrap = 0
-      if ( ( $max_prop_len + $sep_len + 4 ) >= $options{save_wrapped_len} );
+        if ( ( $max_prop_len + $sep_len + 4 ) >= $options{save_wrapped_len} );
 
     # Cycle thru' properties
     my $_sorter = $options{save_sorter};
     foreach my $key ( sort $_sorter keys %props ) {
-      next unless defined $props{$key};
+        next unless defined $props{$key};
         my $value = $props{$key};
-        $value = '' if not defined $value;
 
         # Split value into tokens
         my @raw_value_tokens;
         if ( ref($value) ) {
             croak "${key}'s value is an invalid reference!"
-              unless ( ref($value) eq 'ARRAY' );
+                unless ( ref($value) eq 'ARRAY' );
             @raw_value_tokens = @{$value};
-        } ## end if ( ref($value) )
+        }
         else {
             @raw_value_tokens = ($value);
         }
@@ -821,22 +807,14 @@ sub _save {
         # Escape
         $key = _esc_key($key);
         my @value_tokens;
-        foreach my $_rvt (@raw_value_tokens) {
-            $_rvt = '' unless defined $_rvt;
-            if ( defined $options{token_delimiter} ) {
-                push @value_tokens,
-                  _esc_delim( _esc_val( Encode::encode_utf8($_rvt) ),
-                    $options{token_delimiter} );
-            } ## end if ( defined $options{...})
-            else {
-                push @value_tokens, _esc_val( Encode::encode_utf8($_rvt) );
-            }
-        } ## end foreach my $_rvt (@raw_value_tokens)
+        foreach ( grep { defined $_ } @raw_value_tokens ) {
+            push @value_tokens, _esc_val( Encode::encode_utf8($_) );
+        }
 
         # Save
         if ( $options{save_combine_tokens} ) {
             croak "Cannot combine tokens without a delimiter!"
-              unless defined $options{token_delimiter};
+                unless defined $options{token_delimiter};
 
             # Get delimiter
             # Append a whitespace to it for read-ability
@@ -850,11 +828,9 @@ sub _save {
             if ($do_wrap) {
                 $_val_str = _wrap(
                     {
-                        string  => $_val_str,
-                        options => {
-                            %options,
-                            key_len => length($key) + $sep_len,
-                        },
+                        string => $_val_str,
+                        options =>
+                            { %options, key_len => length($key) + $sep_len, },
                     }
                 );
             } ## end if ($do_wrap)
@@ -878,8 +854,7 @@ sub _save {
                         {
                             string  => $token,
                             options => {
-                                %options,
-                                key_len => length($key) + $sep_len,
+                                %options, key_len => length($key) + $sep_len,
                             },
                         }
                     );
@@ -899,7 +874,7 @@ sub _save {
     $out_str .= "\n" . fullchomp( $options{save_footer} ) . "\n\n";
 
     # Done
-  return $out_str;
+    return $out_str;
 } ## end sub _save
 
 #######################
@@ -917,7 +892,7 @@ sub _sep_regex {
     #   3. Whitespace
     # Where neither of them are backslash escaped
     # Also, any surrounding whitespace is ignored
-  return qr{\s*(?: (?: (?<!\\) [\=\:\s] ) )\s*}x;
+    return qr{\s*(?: (?: (?<!\\) [\=\:\s] ) )\s*}x;
 } ## end sub _sep_regex
 
 # =====================
@@ -938,28 +913,18 @@ sub _esc_key {
     # Escape whitespace
     $key =~ s{\s}{'\ '}gex;
 
-  return $key;
+    return $key;
 } ## end sub _esc_key
 
-
 sub _esc_val {
     my ($val) = @_;
 
     # Escape unprintable
     $val =~ s{([^\x20-\x7e])}{sprintf ("\\u%04x", ord $1)}gex;
 
-  return $val;
+    return $val;
 } ## end sub _esc_val
 
-
-sub _esc_delim {
-    my ( $val, $delim ) = @_;
-  return $val if not defined $delim;
-  return $val if not hascontent($delim);
-  return $val if not hascontent($val);
-  return join( "\\$delim ", _split_tokens( $val, $delim ) );
-} ## end sub _esc_delim
-
 # =====================
 # Unescape Routines
 # =====================
@@ -978,26 +943,18 @@ sub _unesc_key {
     # Un-escape whitespace
     $key =~ s{(?<!\\)\\\s}{' '}gex;
 
-  return $key;
+    return $key;
 } ## end sub _unesc_key
 
-
 sub _unesc_val {
     my ($val) = @_;
 
     # Un-escape unprintable
     $val =~ s{\\u([\da-fA-F]{4})}{chr(hex($1))}gex;
 
-  return $val;
+    return $val;
 } ## end sub _unesc_val
 
-
-sub _unesc_delim {
-    my ( $val, $delim ) = @_;
-    $val =~ s{ \\ $delim }{$delim}gxi;
-  return $val;
-} ## end sub _unesc_delim
-
 # =====================
 # VALUE WRAPPER
 # =====================
@@ -1009,7 +966,7 @@ sub _wrap {
     # Wrap column width
     my $wrap_to = $options{save_wrapped_len} - $options{key_len};
 
-    ## no critic (PackageVars)
+## no critic (PackageVars)
 
     # Text::Wrap settings
     local $Text::Wrap::columns   = $wrap_to;      # Columns
@@ -1018,11 +975,11 @@ sub _wrap {
     local $Text::Wrap::separator = "\\\n";        # Use a '\' separator
     local $Text::Wrap::huge = 'overflow';  # Leave unbreakable lines alone
 
-    ## use critic
+## use critic
 
     # Wrap
     my $wrapped = Text::Wrap::wrap(
-        '',  # Initial tab is empty
+        '',                                # Initial tab is empty
         ' ' x ( $options{key_len} + 1 ), # Subseq tab is aligned to end of key
         $text,                           # Text to wrap
     );
@@ -1031,17 +988,9 @@ sub _wrap {
     $wrapped = fullchomp($wrapped);
 
     # Return
-  return $wrapped;
+    return $wrapped;
 } ## end sub _wrap
 
-# =====================
-# TOKEN SPLITTER
-# =====================
-sub _split_tokens {
-    my ( $val, $delim ) = @_;
-  return split( qr/(?<!\\) $delim \s*/x, $val );
-} ## end sub _split_tokens
-
 #######################
 1;
 
@@ -1221,9 +1170,9 @@ before returning.
 
 =item save_combine_tokens
 
-When true, keys with multiple values are joined using the I<<
-token_delimiter >> and written to a single line. Otherwise they are
-saved/written on multiple lines. Defaults to false.
+When true, keys with multiple values are saved/written on multiple
+lines. Otherwise they are joined using a C<< ', ' >> and written to a
+single line. Defaults to true.
 
 =item save_wrapped
 
@@ -1495,8 +1444,10 @@ This method can also be called using the C<< clear() >> alias.
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests at
-L<https://github.com/mithun/perl-config-properties-commons/issues>
+Please report any bugs or feature requests to
+C<bug-config-properties-commons@rt.cpan.org>, or through the web
+interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Config-Properties-Commons>
 
 =head1 TODO
 
@@ -1508,7 +1459,7 @@ Mithun Ayachit C<mithun@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2014, Mithun Ayachit. All rights reserved.
+Copyright (c) 2012, Mithun Ayachit. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>.
